==> org-lsst-sal-camera-2.6.3-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Carousel_Socket1_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Carousel_Socket1_TrendingTelemetry extends CameraTelemetry {
  private final boolean atStandby;

  private final String clampxminus1_clampState;

  private final int clampxminus1_filterPositionSensorValue;

  private final int clampxminus1_filterPresenceOffset2;

  private final String clampxminus1_filterPresenceStatus;

  private final int clampxminus1_lockSensorOffset1;

  private final int clampxminus1_lockSensorValue;

  private final String clampxminus1_lockStatus;

  private final String clampxplus1_clampState;

  private final int clampxplus1_filterPositionSensorValue;

  private final int clampxplus1_filterPresenceOffset2;

  private final String clampxplus1_filterPresenceStatus;

  private final int clampxplus1_lockSensorOffset1;

  private final int clampxplus1_lockSensorValue;

  private final String clampxplus1_lockStatus;

  private final String clampsState;

  private final boolean empty;

  private final int filterID;

  private final String ioStatus;

  public Fcs_Carousel_Socket1_TrendingTelemetry(boolean atStandby, String clampxminus1_clampState,
      int clampxminus1_filterPositionSensorValue, int clampxminus1_filterPresenceOffset2,
      String clampxminus1_filterPresenceStatus, int clampxminus1_lockSensorOffset1,
      int clampxminus1_lockSensorValue, String clampxminus1_lockStatus,
      String clampxplus1_clampState, int clampxplus1_filterPositionSensorValue,
      int clampxplus1_filterPresenceOffset2, String clampxplus1_filterPresenceStatus,
      int clampxplus1_lockSensorOffset1, int clampxplus1_lockSensorValue,
      String clampxplus1_lockStatus, String clampsState, boolean empty, int filterID,
      String ioStatus) {
    this.atStandby = atStandby;
    this.clampxminus1_clampState = clampxminus1_clampState;
    this.clampxminus1_filterPositionSensorValue = clampxminus1_filterPositionSensorValue;
    this.clampxminus1_filterPresenceOffset2 = clampxminus1_filterPresenceOffset2;
    this.clampxminus1_filterPresenceStatus = clampxminus1_filterPresenceStatus;
    this.clampxminus1_lockSensorOffset1 = clampxminus1_lockSensorOffset1;
    this.clampxminus1_lockSensorValue = clampxminus1_lockSensorValue;
    this.clampxminus1_lockStatus = clampxminus1_lockStatus;
    this.clampxplus1_clampState = clampxplus1_clampState;
    this.clampxplus1_filterPositionSensorValue = clampxplus1_filterPositionSensorValue;
    this.clampxplus1_filterPresenceOffset2 = clampxplus1_filterPresenceOffset2;
    this.clampxplus1_filterPresenceStatus = clampxplus1_filterPresenceStatus;
    this.clampxplus1_lockSensorOffset1 = clampxplus1_lockSensorOffset1;
    this.clampxplus1_lockSensorValue = clampxplus1_lockSensorValue;
    this.clampxplus1_lockStatus = clampxplus1_lockStatus;
    this.clampsState = clampsState;
    this.empty = empty;
    this.filterID = filterID;
    this.ioStatus = ioStatus;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public String getClampxminus1_clampState() {
    return clampxminus1_clampState;
  }

  public int getClampxminus1_filterPositionSensorValue() {
    return clampxminus1_filterPositionSensorValue;
  }

  public int getClampxminus1_filterPresenceOffset2() {
    return clampxminus1_filterPresenceOffset2;
  }

  public String getClampxminus1_filterPresenceStatus() {
    return clampxminus1_filterPresenceStatus;
  }

  public int getClampxminus1_lockSensorOffset1() {
    return clampxminus1_lockSensorOffset1;
  }

  public int getClampxminus1_lockSensorValue() {
    return clampxminus1_lockSensorValue;
  }

  public String getClampxminus1_lockStatus() {
    return clampxminus1_lockStatus;
  }

  public String getClampxplus1_clampState() {
    return clampxplus1_clampState;
  }

  public int getClampxplus1_filterPositionSensorValue() {
    return clampxplus1_filterPositionSensorValue;
  }

  public int getClampxplus1_filterPresenceOffset2() {
    return clampxplus1_filterPresenceOffset2;
  }

  public String getClampxplus1_filterPresenceStatus() {
    return clampxplus1_filterPresenceStatus;
  }

  public int getClampxplus1_lockSensorOffset1() {
    return clampxplus1_lockSensorOffset1;
  }

  public int getClampxplus1_lockSensorValue() {
    return clampxplus1_lockSensorValue;
  }

  public String getClampxplus1_lockStatus() {
    return clampxplus1_lockStatus;
  }

  public String getClampsState() {
    return clampsState;
  }

  public boolean isEmpty() {
    return empty;
  }

  public int getFilterID() {
    return filterID;
  }

  public String getIoStatus() {
    return ioStatus;
  }

  @Override
  public String toString() {
    return "Fcs_Carousel_Socket1_TrendingTelemetry{" + "atStandby=" + atStandby +
        ", clampxminus1_clampState=" + clampxminus1_clampState +
        ", clampxminus1_filterPositionSensorValue=" + clampxminus1_filterPositionSensorValue +
        ", clampxminus1_filterPresenceOffset2=" + clampxminus1_filterPresenceOffset2 +
        ", clampxminus1_filterPresenceStatus=" + clampxminus1_filterPresenceStatus +
        ", clampxminus1_lockSensorOffset1=" + clampxminus1_lockSensorOffset1 +
        ", clampxminus1_lockSensorValue=" + clampxminus1_lockSensorValue +
        ", clampxminus1_lockStatus=" + clampxminus1_lockStatus +
        ", clampxplus1_clampState=" + clampxplus1_clampState +
        ", clampxplus1_filterPositionSensorValue=" + clampxplus1_filterPositionSensorValue +
        ", clampxplus1_filterPresenceOffset2=" + clampxplus1_filterPresenceOffset2 +
        ", clampxplus1_filterPresenceStatus=" + clampxplus1_filterPresenceStatus +
        ", clampxplus1_lockSensorOffset1=" + clampxplus1_lockSensorOffset1 +
        ", clampxplus1_lockSensorValue=" + clampxplus1_lockSensorValue +
        ", clampxplus1_lockStatus=" + clampxplus1_lockStatus +", clampsState=" + clampsState +
        ", empty=" + empty +", filterID=" + filterID +", ioStatus=" + ioStatus +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean atStandby;

    private String clampxminus1_clampState;

    private int clampxminus1_filterPositionSensorValue;

    private int clampxminus1_filterPresenceOffset2;

    private String clampxminus1_filterPresenceStatus;

    private int clampxminus1_lockSensorOffset1;

    private int clampxminus1_lockSensorValue;

    private String clampxminus1_lockStatus;

    private String clampxplus1_clampState;

    private int clampxplus1_filterPositionSensorValue;

    private int clampxplus1_filterPresenceOffset2;

    private String clampxplus1_filterPresenceStatus;

    private int clampxplus1_lockSensorOffset1;

    private int clampxplus1_lockSensorValue;

    private String clampxplus1_lockStatus;

    private String clampsState;

    private boolean empty;

    private int filterID;

    private String ioStatus;

    private Builder() {
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder clampxminus1_clampState(String clampxminus1_clampState) {
      this.clampxminus1_clampState = clampxminus1_clampState;
      return this;
    }

    public Builder clampxminus1_filterPositionSensorValue(
        int clampxminus1_filterPositionSensorValue) {
      this.clampxminus1_filterPositionSensorValue = clampxminus1_filterPositionSensorValue;
      return this;
    }

    public Builder clampxminus1_filterPresenceOffset2(int clampxminus1_filterPresenceOffset2) {
      this.clampxminus1_filterPresenceOffset2 = clampxminus1_filterPresenceOffset2;
      return this;
    }

    public Builder clampxminus1_filterPresenceStatus(String clampxminus1_filterPresenceStatus) {
      this.clampxminus1_filterPresenceStatus = clampxminus1_filterPresenceStatus;
      return this;
    }

    public Builder clampxminus1_lockSensorOffset1(int clampxminus1_lockSensorOffset1) {
      this.clampxminus1_lockSensorOffset1 = clampxminus1_lockSensorOffset1;
      return this;
    }

    public Builder clampxminus1_lockSensorValue(int clampxminus1_lockSensorValue) {
      this.clampxminus1_lockSensorValue = clampxminus1_lockSensorValue;
      return this;
    }

    public Builder clampxminus1_lockStatus(String clampxminus1_lockStatus) {
      this.clampxminus1_lockStatus = clampxminus1_lockStatus;
      return this;
    }

    public Builder clampxplus1_clampState(String clampxplus1_clampState) {
      this.clampxplus1_clampState = clampxplus1_clampState;
      return this;
    }

    public Builder clampxplus1_filterPositionSensorValue(
        int clampxplus1_filterPositionSensorValue) {
      this.clampxplus1_filterPositionSensorValue = clampxplus1_filterPositionSensorValue;
      return this;
    }

    public Builder clampxplus1_filterPresenceOffset2(int clampxplus1_filterPresenceOffset2) {
      this.clampxplus1_filterPresenceOffset2 = clampxplus1_filterPresenceOffset2;
      return this;
    }

    public Builder clampxplus1_filterPresenceStatus(String clampxplus1_filterPresenceStatus) {
      this.clampxplus1_filterPresenceStatus = clampxplus1_filterPresenceStatus;
      return this;
    }

    public Builder clampxplus1_lockSensorOffset1(int clampxplus1_lockSensorOffset1) {
      this.clampxplus1_lockSensorOffset1 = clampxplus1_lockSensorOffset1;
      return this;
    }

    public Builder clampxplus1_lockSensorValue(int clampxplus1_lockSensorValue) {
      this.clampxplus1_lockSensorValue = clampxplus1_lockSensorValue;
      return this;
    }

    public Builder clampxplus1_lockStatus(String clampxplus1_lockStatus) {
      this.clampxplus1_lockStatus = clampxplus1_lockStatus;
      return this;
    }

    public Builder clampsState(String clampsState) {
      this.clampsState = clampsState;
      return this;
    }

    public Builder empty(boolean empty) {
      this.empty = empty;
      return this;
    }

    public Builder filterID(int filterID) {
      this.filterID = filterID;
      return this;
    }

    public Builder ioStatus(String ioStatus) {
      this.ioStatus = ioStatus;
      return this;
    }

    public Fcs_Carousel_Socket1_TrendingTelemetry build() {
      return new Fcs_Carousel_Socket1_TrendingTelemetry(atStandby, clampxminus1_clampState, clampxminus1_filterPositionSensorValue, clampxminus1_filterPresenceOffset2, clampxminus1_filterPresenceStatus, clampxminus1_lockSensorOffset1, clampxminus1_lockSensorValue, clampxminus1_lockStatus, clampxplus1_clampState, clampxplus1_filterPositionSensorValue, clampxplus1_filterPresenceOffset2, clampxplus1_filterPresenceStatus, clampxplus1_lockSensorOffset1, clampxplus1_lockSensorValue, clampxplus1_lockStatus, clampsState, empty, filterID, ioStatus);
    }
  }
}

==> org-lsst-sal-camera-3.0.1-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Carousel_Socket1_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Carousel_Socket1_TrendingTelemetry extends CameraTelemetry {
  private final boolean atStandby;

  private final String clampxminus1_clampState;

  private final int clampxminus1_filterPositionSensorValue;

  private final int clampxminus1_filterPresenceOffset2;

  private final String clampxminus1_filterPresenceStatus;

  private final int clampxminus1_lockSensorOffset1;

  private final int clampxminus1_lockSensorValue;

  private final String clampxminus1_lockStatus;

  private final String clampxplus1_clampState;

  private final int clampxplus1_filterPositionSensorValue;

  private final int clampxplus1_filterPresenceOffset2;

  private final String clampxplus1_filterPresenceStatus;

  private final int clampxplus1_lockSensorOffset1;

  private final int clampxplus1_lockSensorValue;

  private final String clampxplus1_lockStatus;

  private final String clampsState;

  private final boolean empty;

  private final String filterName;

  private final String ioStatus;

  private final int socketID;

  public Fcs_Carousel_Socket1_TrendingTelemetry(boolean atStandby, String clampxminus1_clampState,
      int clampxminus1_filterPositionSensorValue, int clampxminus1_filterPresenceOffset2,
      String clampxminus1_filterPresenceStatus, int clampxminus1_lockSensorOffset1,
      int clampxminus1_lockSensorValue, String clampxminus1_lockStatus,
      String clampxplus1_clampState, int clampxplus1_filterPositionSensorValue,
      int clampxplus1_filterPresenceOffset2, String clampxplus1_filterPresenceStatus,
      int clampxplus1_lockSensorOffset1, int clampxplus1_lockSensorValue,
      String clampxplus1_lockStatus, String clampsState, boolean empty, String filterName,
      String ioStatus, int socketID) {
    this.atStandby = atStandby;
    this.clampxminus1_clampState = clampxminus1_clampState;
    this.clampxminus1_filterPositionSensorValue = clampxminus1_filterPositionSensorValue;
    this.clampxminus1_filterPresenceOffset2 = clampxminus1_filterPresenceOffset2;
    this.clampxminus1_filterPresenceStatus = clampxminus1_filterPresenceStatus;
    this.clampxminus1_lockSensorOffset1 = clampxminus1_lockSensorOffset1;
    this.clampxminus1_lockSensorValue = clampxminus1_lockSensorValue;
    this.clampxminus1_lockStatus = clampxminus1_lockStatus;
    this.clampxplus1_clampState = clampxplus1_clampState;
    this.clampxplus1_filterPositionSensorValue = clampxplus1_filterPositionSensorValue;
    this.clampxplus1_filterPresenceOffset2 = clampxplus1_filterPresenceOffset2;
    this.clampxplus1_filterPresenceStatus = clampxplus1_filterPresenceStatus;
    this.clampxplus1_lockSensorOffset1 = clampxplus1_lockSensorOffset1;
    this.clampxplus1_lockSensorValue = clampxplus1_lockSensorValue;
    this.clampxplus1_lockStatus = clampxplus1_lockStatus;
    this.clampsState = clampsState;
    this.empty = empty;
    this.filterName = filterName;
    this.ioStatus = ioStatus;
    this.socketID = socketID;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public String getClampxminus1_clampState() {
    return clampxminus1_clampState;
  }

  public int getClampxminus1_filterPositionSensorValue() {
    return clampxminus1_filterPositionSensorValue;
  }

  public int getClampxminus1_filterPresenceOffset2() {
    return clampxminus1_filterPresenceOffset2;
  }

  public String getClampxminus1_filterPresenceStatus() {
    return clampxminus1_filterPresenceStatus;
  }

  public int getClampxminus1_lockSensorOffset1() {
    return clampxminus1_lockSensorOffset1;
  }

  public int getClampxminus1_lockSensorValue() {
    return clampxminus1_lockSensorValue;
  }

  public String getClampxminus1_lockStatus() {
    return clampxminus1_lockStatus;
  }

  public String getClampxplus1_clampState() {
    return clampxplus1_clampState;
  }

  public int getClampxplus1_filterPositionSensorValue() {
    return clampxplus1_filterPositionSensorValue;
  }

  public int getClampxplus1_filterPresenceOffset2() {
    return clampxplus1_filterPresenceOffset2;
  }

  public String getClampxplus1_filterPresenceStatus() {
    return clampxplus1_filterPresenceStatus;
  }

  public int getClampxplus1_lockSensorOffset1() {
    return clampxplus1_lockSensorOffset1;
  }

  public int getClampxplus1_lockSensorValue() {
    return clampxplus1_lockSensorValue;
  }

  public String getClampxplus1_lockStatus() {
    return clampxplus1_lockStatus;
  }

  public String getClampsState() {
    return clampsState;
  }

  public boolean isEmpty() {
    return empty;
  }

  public String getFilterName() {
    return filterName;
  }

  public String getIoStatus() {
    return ioStatus;
  }

  public int getSocketID() {
    return socketID;
  }

  @Override
  public String toString() {
    return "Fcs_Carousel_Socket1_TrendingTelemetry{" + "atStandby=" + atStandby +
        ", clampxminus1_clampState=" + clampxminus1_clampState +
        ", clampxminus1_filterPositionSensorValue=" + clampxminus1_filterPositionSensorValue +
        ", clampxminus1_filterPresenceOffset2=" + clampxminus1_filterPresenceOffset2 +
        ", clampxminus1_filterPresenceStatus=" + clampxminus1_filterPresenceStatus +
        ", clampxminus1_lockSensorOffset1=" + clampxminus1_lockSensorOffset1 +
        ", clampxminus1_lockSensorValue=" + clampxminus1_lockSensorValue +
        ", clampxminus1_lockStatus=" + clampxminus1_lockStatus +
        ", clampxplus1_clampState=" + clampxplus1_clampState +
        ", clampxplus1_filterPositionSensorValue=" + clampxplus1_filterPositionSensorValue +
        ", clampxplus1_filterPresenceOffset2=" + clampxplus1_filterPresenceOffset2 +
        ", clampxplus1_filterPresenceStatus=" + clampxplus1_filterPresenceStatus +
        ", clampxplus1_lockSensorOffset1=" + clampxplus1_lockSensorOffset1 +
        ", clampxplus1_lockSensorValue=" + clampxplus1_lockSensorValue +
        ", clampxplus1_lockStatus=" + clampxplus1_lockStatus +", clampsState=" + clampsState +
        ", empty=" + empty +", filterName=" + filterName +", ioStatus=" + ioStatus +
        ", socketID=" + socketID +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean atStandby;

    private String clampxminus1_clampState;

    private int clampxminus1_filterPositionSensorValue;

    private int clampxminus1_filterPresenceOffset2;

    private String clampxminus1_filterPresenceStatus;

    private int clampxminus1_lockSensorOffset1;

    private int clampxminus1_lockSensorValue;

    private String clampxminus1_lockStatus;

    private String clampxplus1_clampState;

    private int clampxplus1_filterPositionSensorValue;

    private int clampxplus1_filterPresenceOffset2;

    private String clampxplus1_filterPresenceStatus;

    private int clampxplus1_lockSensorOffset1;

    private int clampxplus1_lockSensorValue;

    private String clampxplus1_lockStatus;

    private String clampsState;

    private boolean empty;

    private String filterName;

    private String ioStatus;

    private int socketID;

    private Builder() {
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder clampxminus1_clampState(String clampxminus1_clampState) {
      this.clampxminus1_clampState = clampxminus1_clampState;
      return this;
    }

    public Builder clampxminus1_filterPositionSensorValue(
        int clampxminus1_filterPositionSensorValue) {
      this.clampxminus1_filterPositionSensorValue = clampxminus1_filterPositionSensorValue;
      return this;
    }

    public Builder clampxminus1_filterPresenceOffset2(int clampxminus1_filterPresenceOffset2) {
      this.clampxminus1_filterPresenceOffset2 = clampxminus1_filterPresenceOffset2;
      return this;
    }

    public Builder clampxminus1_filterPresenceStatus(String clampxminus1_filterPresenceStatus) {
      this.clampxminus1_filterPresenceStatus = clampxminus1_filterPresenceStatus;
      return this;
    }

    public Builder clampxminus1_lockSensorOffset1(int clampxminus1_lockSensorOffset1) {
      this.clampxminus1_lockSensorOffset1 = clampxminus1_lockSensorOffset1;
      return this;
    }

    public Builder clampxminus1_lockSensorValue(int clampxminus1_lockSensorValue) {
      this.clampxminus1_lockSensorValue = clampxminus1_lockSensorValue;
      return this;
    }

    public Builder clampxminus1_lockStatus(String clampxminus1_lockStatus) {
      this.clampxminus1_lockStatus = clampxminus1_lockStatus;
      return this;
    }

    public Builder clampxplus1_clampState(String clampxplus1_clampState) {
      this.clampxplus1_clampState = clampxplus1_clampState;
      return this;
    }

    public Builder clampxplus1_filterPositionSensorValue(
        int clampxplus1_filterPositionSensorValue) {
      this.clampxplus1_filterPositionSensorValue = clampxplus1_filterPositionSensorValue;
      return this;
    }

    public Builder clampxplus1_filterPresenceOffset2(int clampxplus1_filterPresenceOffset2) {
      this.clampxplus1_filterPresenceOffset2 = clampxplus1_filterPresenceOffset2;
      return this;
    }

    public Builder clampxplus1_filterPresenceStatus(String clampxplus1_filterPresenceStatus) {
      this.clampxplus1_filterPresenceStatus = clampxplus1_filterPresenceStatus;
      return this;
    }

    public Builder clampxplus1_lockSensorOffset1(int clampxplus1_lockSensorOffset1) {
      this.clampxplus1_lockSensorOffset1 = clampxplus1_lockSensorOffset1;
      return this;
    }

    public Builder clampxplus1_lockSensorValue(int clampxplus1_lockSensorValue) {
      this.clampxplus1_lockSensorValue = clampxplus1_lockSensorValue;
      return this;
    }

    public Builder clampxplus1_lockStatus(String clampxplus1_lockStatus) {
      this.clampxplus1_lockStatus = clampxplus1_lockStatus;
      return this;
    }

    public Builder clampsState(String clampsState) {
      this.clampsState = clampsState;
      return this;
    }

    public Builder empty(boolean empty) {
      this.empty = empty;
      return this;
    }

    public Builder filterName(String filterName) {
      this.filterName = filterName;
      return this;
    }

    public Builder ioStatus(String ioStatus) {
      this.ioStatus = ioStatus;
      return this;
    }

    public Builder socketID(int socketID) {
      this.socketID = socketID;
      return this;
    }

    public Fcs_Carousel_Socket1_TrendingTelemetry build() {
      return new Fcs_Carousel_Socket1_TrendingTelemetry(atStandby, clampxminus1_clampState, clampxminus1_filterPositionSensorValue, clampxminus1_filterPresenceOffset2, clampxminus1_filterPresenceStatus, clampxminus1_lockSensorOffset1, clampxminus1_lockSensorValue, clampxminus1_lockStatus, clampxplus1_clampState, clampxplus1_filterPositionSensorValue, clampxplus1_filterPresenceOffset2, clampxplus1_filterPresenceStatus, clampxplus1_lockSensorOffset1, clampxplus1_lockSensorValue, clampxplus1_lockStatus, clampsState, empty, filterName, ioStatus, socketID);
    }
  }
}
